@@ -17,7 +17,7 @@ use Carp qw/croak/;
 use List::Util qw/shuffle/;
 use Scalar::Util qw/looks_like_number/;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 my $DEG_IN_SCALE = 12;
 
@@ -444,6 +444,8 @@ my $PCS2FORTE = {
   '0,4,8'              => '3-12',
 };
 
+my $FORTE_NUMBER_RE = qr/[3-9]-[zZ]?\d{1,2}/;
+
 ########################################################################
 #
 # SUBROUTINES
@@ -641,6 +643,10 @@ sub complement {
 
 sub fnums { $FORTE2PCS }
 
+sub forte_number_re {
+  return $FORTE_NUMBER_RE;
+}
+
 sub forte2pcs {
   my ( $self, $forte_number ) = @_;
   return $FORTE2PCS->{ lc $forte_number };
@@ -1574,6 +1580,10 @@ array references to the corresponding pitch sets. This reference should
 perhaps not be fiddled with, unless the fiddler desires different
 results for the B<forte2pcs> and B<pcs2forte> calls.
 
+=head2 B<forte_number_re>
+
+Returns a regular expression capable of matching a Forte Number.
+
 =head2 B<forte2pcs> I<forte_number>
 
 Given a Forte Number (such as C<6-z44> or C<6-Z44>), returns the
